package
Version:
v0.2.0
Opens a new window with list of versions in this module.
Published: Nov 18, 2025
License: MIT
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type CieloResponse[T any] struct {
Status string `json:"status"`
Data T `json:"data,omitempty"`
Message string `json:"message,omitempty"`
}
type Error struct {
Message string `json:"message"`
Status string `json:"status"`
}
Source Files
¶
Directories
¶
Click to show internal directories.
Click to hide internal directories.